@@ -7,12 +7,14 @@
 # nor does it submit to any jurisdiction.
 #
 
-import numpy as np
-import climetlab
-from importlib import import_module
-from climetlab.core.plugins import find_plugin
 import os
+from importlib import import_module
+
 import yaml
+
+import climetlab
+from climetlab.core.metadata import annotate
+from climetlab.core.plugins import find_plugin
 from climetlab.utils.html import table
 
 
@@ -45,6 +47,8 @@ class Dataset:
         return self.source[n]
 
     def to_numpy(self, *args, **kwargs):
+        import numpy as np
+
         return np.array([s.to_numpy(*args, **kwargs) for s in self.source])
 
     def to_xarray(self, *args, **kwargs):
@@ -59,6 +63,9 @@ class Dataset:
     def _repr_html_(self):
         return table(self)
 
+    def annotate(self, data, **kargs):
+        return annotate(data, self, **kargs)
+
 
 def _module_callback(plugin):
     return import_module(plugin, package=__name__).dataset
