@@ -7,21 +7,28 @@
 # nor does it submit to any jurisdiction.
 #
 
-from . import Dataset
-from climetlab.utils.domains import domain_to_area
 from climetlab import load_source
+from climetlab.utils.datetime import to_datetime
+from climetlab.utils.domains import domain_to_area
+
+from . import Dataset
 
 
 class Era5SingleLevels(Dataset):
     def __init__(self, variable, period, domain=None, time=None, grid=None):
 
-        request = dict(variable=variable, product_type="reanalysis",)
+        request = dict(
+            variable=variable,
+            product_type="reanalysis",
+        )
 
         if domain is not None:
             request["area"] = domain_to_area(domain)
 
         if time is not None:
             request["time"] = time
+        else:
+            request["time"] = list(range(0, 24))
 
         if grid is not None:
             if isinstance(grid, (int, float)):
@@ -32,6 +39,9 @@ class Era5SingleLevels(Dataset):
         if isinstance(period, int):
             period = (period, period)
 
+        if isinstance(period, (tuple, list)) and len(period) == 1:
+            period = (period[0], period[0])
+
         sources = []
         for year in range(period[0], period[1] + 1):
             request["year"] = year
@@ -41,5 +51,17 @@ class Era5SingleLevels(Dataset):
 
         self.source = load_source("multi", sources)
 
+    def __getitem__(self, n):
+        # TODO: move to superclass
+        if isinstance(n, int):
+            return super().__getitem__(n)
+
+        n = to_datetime(n)
+        for field in self:
+            if field.datetime() == n:
+                return field
+
+        raise KeyError(n)
+
 
 dataset = Era5SingleLevels
