@@ -3,10 +3,11 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
+import sys
 from importlib import import_module
 
 HELPERS = {
@@ -30,6 +31,10 @@ def helper(data, *args, **kwargs):
 
     if name is not None:
         helper = import_module(".%s" % (name,), package=__name__)
-        return helper.helper(data, *args, **kwargs)
+        try:
+            return helper.helper(data, *args, **kwargs)
+        except Exception:
+            print(helper, file=sys.stderr)
+            raise
 
     raise ValueError("Cannot find a helper for class %s" % (fullname,))
