@@ -68,10 +68,25 @@ class GribField:
         self.handle = handle
         self.path = path
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        # Place to suppress exceptions (don't reraise the passed-in exception, it is the caller's responsibility)
+        pass
+
     @property
     def values(self):
         return self.handle.get("values")
 
+    @property
+    def offset(self):
+        return int(self.handle.get("offset"))
+
+    @property
+    def shape(self):
+        return self.handle.get("Nj"), self.handle.get("Ni")
+
     def plot_map(self, driver):
         driver.bounding_box(
             north=self.handle.get("latitudeOfFirstGridPointInDegrees"),
@@ -82,11 +97,7 @@ class GribField:
         driver.plot_grib(self.path, self.handle.get("offset"))
 
     def to_numpy(self):
-        return self.values.reshape((self.handle.get("Nj"), self.handle.get("Ni")))
-
-    @property
-    def offset(self):
-        return int(self.handle.get("offset"))
+        return self.values.reshape(self.shape)
 
     def __repr__(self):
         return "GribField(%s,%s,%s,%s,%s,%s)" % (
@@ -110,11 +121,10 @@ class GribField:
 
     def metadata(self):
         m = {}
-        for n in ("shortName", "units"):
+        for n in ("shortName", "units", "paramId"):
             p = self.handle.get(n)
             if p is not None:
                 m[n] = str(p)
-
         return m
 
     def datetime(self):
@@ -124,6 +134,10 @@ class GribField:
             date // 10000, date % 10000 // 100, date % 100, time // 100, time % 100
         )
 
+    def valid_datetime(self):
+        step = self.handle.get("endStep")
+        return self.datetime() + datetime.timedelta(hours=step)
+
 
 class GRIBIterator:
     def __init__(self, path):
